aboutsummaryrefslogtreecommitdiffstats
path: root/epan/packet_info.h
diff options
context:
space:
mode:
Diffstat (limited to 'epan/packet_info.h')
-rw-r--r--epan/packet_info.h5
1 files changed, 2 insertions, 3 deletions
diff --git a/epan/packet_info.h b/epan/packet_info.h
index 95e1045f46..49f444e76f 100644
--- a/epan/packet_info.h
+++ b/epan/packet_info.h
@@ -200,9 +200,8 @@ typedef struct _packet_info {
guint8 zbee_stack_vers; /* ZigBee stack version number, present in the ZigBee network layer, but
* impacts the packet format at all layers of the ZigBee stack.
*/
- int link_dir; /* 3GPP messages are sometime different UP link(UL) or Downlink(DL)
- *
- */
+ int link_dir; /* 3GPP messages are sometime different UP link(UL) or Downlink(DL) */
+ GSList* dependent_frames; /* A list of frames which this one depends on */
} packet_info;
/* For old code that hasn't yet been changed. */